<?php

/* http://www.itnetwork.cz */
class Db
{
    /**
     * @var PDO Databázové spojení
     */
    private static $connection;

    /**
     * @var array Výchozí nastavení ovladače
     */
    private static $options = array(
        PDO::ATTR_ERRMODE => PDO::ERRMODE_WARNING,
        PDO::MYSQL_ATTR_INIT_COMMAND => "SET NAMES utf8",
        PDO::ATTR_EMULATE_PREPARES => false
    );

    /**
     * Připojí se k databázi pomocí daných údajů
     */
    public static function connect()
    {
        // Nastaví údaje k připojení k databázi
        $host = 'phpmyadmin';
        $database = 'phpmachr';
        $user = 'root';
        $password = 'password';
        
        if (!isset(self::$connection)) {
            $dsn = "mysql:host=$host;dbname=$database";
            self::$connection = new PDO($dsn, $user, $password, self::$options);
        }
    }

    /**
     * Spustí dotaz a vrátí z něj první řádek
     * @param string $query Dotaz
     * @param array $parameters Parametry
     * @return mixed Pole výsledku nebo false
     */
    public static function queryOne($query, $parameters = array()) {
        $statement = self::$connection->prepare($query);
        $statement->execute($parameters);
        return $statement->fetch();
    }

    /**
     * Spustí dotaz a vrátí z něj všechny řádky
     * @param string $query Dotaz
     * @param array $parameters Parametry
     * @return mixed Pole výsledků nebo false
     */
    public static function queryAll($query, $parameters = array()) {
        $statement = self::$connection->prepare($query);
        $statement->execute($parameters);
        return $statement->fetchAll();
    }

    /**
     * Spustí dotaz a vrátí jedno asociativní pole, jehož klíče a hodnoty
     * odpovídají určitým sloupcům jednotlivých řádků dotazu
     * @param string $query Dotaz
     * @param string $keyColumn Sloupec, který bude klíčem výstupního pole
     * @param string $valueColumn Sloupec, který bude hodnotou výstupního pole
     * @param array $parameters Parametry
     * @return array Asociativní pole
     */
    public static function queryPairs($query, $keyColumn, $valueColumn, $parameters = array()) {
        return ArrayUtils::mapPairs(self::queryAll($query, $parameters), $keyColumn, $valueColumn);
    }

    /**
     * Spustí dotaz a vrátí z něj první sloupec prvního řádku
     * @param string $query Dotaz
     * @param array $parameters Parametry
     * @return mixed První hodnota výsledku dotazu nebo false
     */
    public static function querySingle($query, $parameters = array()) {
        $statement = self::queryOne($query, $parameters);
        return $statement ? $statement[0] : false;
    }

    /**
     * Spustí dotaz a vrátí počet ovlivněných řádků
     * @param string $query Dotaz
     * @param array $parameters Parametry
     * @return int Počet ovlivněných řádků
     */
    public static function query($query, $parameters = array()) {
        $statement = self::$connection->prepare($query);
        $statement->execute($parameters);
        return $statement->rowCount();
    }

    /**
     * Vloží do tabulky nový řádek jako data z asociativního pole
     * @param string $table Název tabulky
     * @param array $parameters Asociativní pole s daty
     * @return int Počet ovlivněných řádků
     */
    public static function insert($table, $parameters = array()) {
        return self::query("INSERT INTO `$table` (`".
            implode('`, `', array_keys($parameters)).
            "`) VALUES (".str_repeat('?,', sizeOf($parameters)-1)."?)",
            array_values($parameters));
    }

    /**
     * Vloží do tabulky sérii řádků jako data z asociativních polí
     * @param string $table Název tabulky
     * @param array $parameters Parametry
     * @return int Počet ovlivněných řádků
     */
    public static function insertAll($table, $parameters = array()) {
        $params = array();
        $query = rtrim("INSERT INTO `$table` (`".
            implode('`, `', array_keys($parameters[0])).
            "`) VALUES " . str_repeat('(' . str_repeat('?,', sizeOf($parameters[0])-1)."?), ", sizeOf($parameters)), ', ');
        foreach ($parameters as $rows)
        {
            $params = array_merge($params, array_values($rows));
        }
        return self::query($query, $params);
    }

    /**
     * Změní řádek v tabulce tak, aby obsahoval data z asociativního pole
     * @param string $table Název tabulky
     * @param array $values Asociativní pole s daty
     * @param string $condition Část SQL dotazu s podmínkou včetně WHERE
     * @param array $parameters Parametry dotazu
     * @return int Počet ovlivněných řádků
     */
    public static function update($table, $values = array(), $condition, $parameters = array()) {
        return self::query("UPDATE `$table` SET `".
            implode('` = ?, `', array_keys($values)).
            "` = ? " . $condition,
            array_merge(array_values($values), $parameters));
    }
    
    /**
     * @return string Vrací ID posledně vloženého záznamu
     */
    public static function getLastId()
    {
        return self::$connection->lastInsertId();
    }
}