$.fn.tooltipster("setDefaults", {
    contentAsHTML: true,
    autoClose: false,
    position: "right"
});

function validateDate(date) {
    if(!/^\d{1,2}.\d{1,2}.\d{4}$/.test(date))
        return false;

    var parts = date.split(".");
    var day = parseInt(parts[0], 10);
    var month = parseInt(parts[1], 10);
    var year = parseInt(parts[2], 10);

    if(year < 1000 || year > 3000 || month == 0 || month > 12)
        return false;

    var monthLength = [ 31, 28, 31, 30, 31, 30, 31, 31, 30, 31, 30, 31 ];

    if(year % 400 == 0 || (year % 100 != 0 && year % 4 == 0))
        monthLength[1] = 29;

    return day > 0 && day <= monthLength[month - 1];
}

function bindRegisterForm(){
    var form = $("#registerForm");

    var notif = $("#notifContainer");
    var icon = $("#notifContainer i");
    var message = $("#notifContainer span");
    var button = $("#notifContainer .button");

    var usernameField = $("#usernameField");
    var emailField = $("#emailField");
    var birthdateField = $("#birthdateField");
    var passwordField = $("#passwordField");
    var passwordAgainField = $("#passwordAgainField");
    var antispamField = $("#antispamField");

    notif.fadeOut(1);
    button.slideUp(1).click(function(){
        form.slideDown(200);
        notif.slideUp(200);
    });

    form.bind("submit", function(e){
        e.preventDefault();

        var username = usernameField.val();
        var email = emailField.val();
        var birthdate = birthdateField.val();
        var password = passwordField.val();
        var passwordAgain = passwordAgainField.val();
        var antispam = antispamField.val();


        $(".tooltipstered").tooltipster("destroy");
        $(".error").removeClass("error");

        //JMÉNO
        if(username == ""){ //JMÉNO: Prázdné
            usernameField.addClass("error");
            usernameField.tooltipster({ content: "Jméno je prázdné." }).tooltipster("show");
        }
        else if(username.length < 6){ //JMÉNO: Menší než 6
            usernameField.addClass("error");
            usernameField.tooltipster({ content: "Jméno je příliš krátké, má být minimálně 6 znaků dlouhé." }).tooltipster("show");
        }
        else if(!/^\w+$/i.test(username)){ //JMÉNO: Neodpovídá
            usernameField.addClass("error");
            usernameField.tooltipster({ content: "Jméno obsahuje nepovolené znaky."}).tooltipster("show");
        }


        //EMAIL
        else if(email == ""){ //EMAIL: Prázdný
            emailField.addClass("error");
            emailField.tooltipster({ content: "E-mailová adresa je prázdná." }).tooltipster("show");
        }
        else if(!/\S+@\S+\.\S+/.test(email)){ //EMAIL: Neodpovídá
            emailField.addClass("error");
            emailField.tooltipster({ content: "E-mailová adresa není v požadovaném formátu. (user@domain.com)" }).tooltipster("show");
        }


        //DATUM NAROZENÍ
        else if(birthdate == ""){ //DATUM NAROZENÍ: Prázdné
            birthdateField.addClass("error");
            birthdateField.tooltipster({ content: "Datum narození je prázdné." }).tooltipster("show");
        }
        else if(!validateDate(birthdate)){ //DATUM NAROZENÍ: Nevalidní
            birthdateField.addClass("error");
            birthdateField.tooltipster({ content: "Datum narození je v nesprávném formátu (dd-mm-yyyy)" }).tooltipster("show");
        }


        //HESLO
        else if(password == ""){ //HESLO: Prázdné
            passwordField.addClass("error");
            passwordField.tooltipster({ content: "Heslo je prázdné." }).tooltipster("show");
        }
        else if(password.length < 6){ //HESLO: Menší než 6
            passwordField.addClass("error");
            passwordField.tooltipster({ content: "Heslo je příliš krátké, má být minimálně 6 znaků dlouhé." }).tooltipster("show");
        }


        //HESLO ZNOVU
        else if(passwordAgain == ""){ //HESLO ZNOVU: Prázdné
            passwordAgainField.addClass("error");
            passwordAgainField.tooltipster({ content: "Opakované heslo je prázdné." }).tooltipster("show");
        }
        else if(password !== passwordAgain){ //HESLO ZNOVU: Nerovná se, nebo je prázdné
            passwordAgainField.addClass("error");
            passwordAgainField.tooltipster({ content: "Hesla se neshodují." }).tooltipster("show");
        }

        //ANTISPAM
        else if(antispam == ""){ //ANTISPAM: Prázdný
            antispamField.addClass("error");
            antispamField.tooltipster({ content: "Antispam je prázdný." }).tooltipster("show");
        }
        /* POZNÁMKA: Antispam nekontroluju na klientovi, co když nějaký robot z tadyma vyhrabe odpověď? */

        else{
            notif.removeClass("red-dark").removeClass("orange-dark").removeClass("green-dark").removeClass("blue-dark");
            icon.attr("class", "");

            notif.addClass("blue-dark");
            icon.addClass("fa fa-fw fa-cog fa-spin");

            message.html("Server zpracovává formulář...");

            button.slideUp(1);
            form.slideUp(200);
            notif.slideDown(200);

            $.ajax({
                type: "POST",
                url: "/register",
                data: form.serialize()
            }).success(function(data, status, jqxhr){
                notif.removeClass("blue-dark");
                icon.attr("class", "");
                message.html("");

                try{
                    var json = JSON.parse(data);

                    if(json.state == "success"){
                        notif.addClass("green-dark");
                        icon.addClass("fa fa-fw fa-check-circle");

                        message.html("Registrace téměř dokončena, na zadaný E-Mail vám příjde aktivační zpráva.");
                    }
                    else if(json.state == "error"){
                        notif.addClass("red-dark");
                        icon.addClass("fa fa-fw fa-times-circle");

                        message.html(json.message);

                        button.slideDown(400);
                    }
                    else{
                        notif.addClass("orange-dark");
                        icon.addClass("fa fa-fw fa-question-circle");
                        message.html("Server odpověděl neznámým stavem.");

                        button.slideDown(400);
                    }
                }
                catch(e){
                    notif.addClass("orange-dark");
                    icon.addClass("fa fa-fw fa-question-circle");

                    message.html("Server odpověděl neznámým stavem.");

                    button.slideDown(800);
                }
            });

        }
    });
}
function bindLoginForm(){
    var form = $("#loginForm");

    var notif = $("#notifContainer");
    var icon = $("#notifContainer i");
    var message = $("#notifContainer span");
    var button = $("#notifContainer .button");

    var emailField = $("#emailField");
    var passwordField = $("#passwordField");

    notif.fadeOut(1);
    button.slideUp(1).click(function(){
        form.slideDown(200);
        notif.slideUp(200);
    });

    form.bind("submit", function(e){
        e.preventDefault();
        var email = emailField.val();
        var password = passwordField.val();


        //EMAIL
        if(email == ""){ //EMAIL: Prázdný
            emailField.addClass("error");
            emailField.tooltipster({ content: "E-mailová adresa je prázdná." }).tooltipster("show");
        }
        else if(!/\S+@\S+\.\S+/.test(email)){
            emailField.addClass("error");
            emailField.tooltipster({ content: "E-mailová adresa je v nepovoleném formátu." }).tooltipster("show");
        }


        //HESLO
        else if(password == ""){ //HESLO: Prázdné
            passwordField.addClass("error");
            passwordField.tooltipster({ content: "Heslo je prázdné." }).tooltipster("show");
        }


        else{
            notif.removeClass("red-dark").removeClass("orange-dark").removeClass("green-dark").removeClass("blue-dark");
            icon.attr("class", "");

            notif.addClass("blue-dark");
            icon.addClass("fa fa-fw fa-cog fa-spin");

            message.html("Server zpracovává formulář...");

            button.slideUp(1);
            form.slideUp(200);
            notif.slideDown(200);

            $.ajax({
                type: "POST",
                url: "/login",
                data: form.serialize()
            }).success(function(data, status, jqxhr){
                notif.removeClass("blue-dark");
                icon.attr("class", "");
                message.html("");

                try{
                    var json = JSON.parse(data);

                    if(json.state == "success"){
                        notif.addClass("green-dark");
                        icon.addClass("fa fa-fw fa-check-circle");

                        message.html("Přihlášení proběhlo úspěšně. Za pár sekund budete přesměrováni.");
                        setTimeout(function(){
                            window.location.href = "/";
                        }, 2000);
                    }
                    else if(json.state == "error"){
                        notif.addClass("red-dark");
                        icon.addClass("fa fa-fw fa-times-circle");

                        message.html(json.message);

                        button.slideDown(400);
                    }
                    else{
                        notif.addClass("orange-dark");
                        icon.addClass("fa fa-fw fa-question-circle");
                        message.html("Server odpověděl neznámým stavem.");

                        button.slideDown(400);
                    }
                }
                catch(e){
                    notif.addClass("orange-dark");
                    icon.addClass("fa fa-fw fa-question-circle");

                    message.html("Server odpověděl neznámým stavem.");

                    button.slideDown(800);
                }
            });
        }
    });
}

function bindForgotPwForm(){
    var form = $("#forgotPwForm");

    var notif = $("#notifContainer");
    var icon = $("#notifContainer i");
    var message = $("#notifContainer span");
    var button = $("#notifContainer .button");

    var emailField = $("#emailField");

    notif.fadeOut(1);
    button.slideUp(1).click(function(){
        form.slideDown(200);
        notif.slideUp(200);
    });

    form.bind("submit", function(e){
        e.preventDefault();
        var email = emailField.val();


        //EMAIL
        if(email == ""){ //EMAIL: Prázdný
            emailField.addClass("error");
            emailField.tooltipster({ content: "E-mailová adresa je prázdná." }).tooltipster("show");
        }
        else if(!/\S+@\S+\.\S+/.test(email)){
            emailField.addClass("error");
            emailField.tooltipster({ content: "E-mailová adresa je v nepovoleném formátu." }).tooltipster("show");
        }

        else{
            notif.removeClass("red-dark").removeClass("orange-dark").removeClass("green-dark").removeClass("blue-dark");
            icon.attr("class", "");

            notif.addClass("blue-dark");
            icon.addClass("fa fa-fw fa-cog fa-spin");

            message.html("Server zpracovává formulář...");

            button.slideUp(1);
            form.slideUp(200);
            notif.slideDown(200);

            $.ajax({
                type: "POST",
                url: "/forgotpw",
                data: form.serialize()
            }).success(function(data, status, jqxhr){
                notif.removeClass("blue-dark");
                icon.attr("class", "");
                message.html("");

                try{
                    var json = JSON.parse(data);

                    if(json.state == "success"){
                        notif.addClass("green-dark");
                        icon.addClass("fa fa-fw fa-check-circle");

                        message.html("Formulář odeslán. Příjde vám E-mail s odkazem na obnovení hesla.");
                    }
                    else if(json.state == "error"){
                        notif.addClass("red-dark");
                        icon.addClass("fa fa-fw fa-times-circle");

                        message.html(json.message);

                        button.slideDown(400);
                    }
                    else{
                        notif.addClass("orange-dark");
                        icon.addClass("fa fa-fw fa-question-circle");
                        message.html("Server odpověděl neznámým stavem.");

                        button.slideDown(400);
                    }
                }
                catch(e){
                    notif.addClass("orange-dark");
                    icon.addClass("fa fa-fw fa-question-circle");

                    message.html("Server odpověděl neznámým stavem.");

                    button.slideDown(800);
                }
            });
        }
    });
}
function bindPwRecoveryForm(){
    var form = $("#pwRecoveryForm");

    var notif = $("#notifContainer");
    var icon = $("#notifContainer i");
    var message = $("#notifContainer span");
    var button = $("#notifContainer .button");

    var passwordField = $("#passwordField");
    var passwordAgainField = $("#passwordFieldAgain");

    notif.fadeOut(1);
    button.slideUp(1).click(function(){
        form.slideDown(200);
        notif.slideUp(200);
    });

    form.bind("submit", function(e){
        e.preventDefault();
        var password = passwordField.val();
        var passwordAgain = passwordAgainField.val();

        //HESLO
        if(password == ""){ //HESLO: Prázdné
            passwordField.addClass("error");
            passwordField.tooltipster({ content: "Heslo je prázdné." }).tooltipster("show");
        }
        else if(password.length < 6){ //HESLO: Menší než 6
            passwordField.addClass("error");
            passwordField.tooltipster({ content: "Heslo je příliš krátké, má být minimálně 6 znaků dlouhé." }).tooltipster("show");
        }


        //HESLO ZNOVU
        else if(passwordAgain == ""){ //HESLO ZNOVU: Prázdné
            passwordAgainField.addClass("error");
            passwordAgainField.tooltipster({ content: "Opakované heslo je prázdné." }).tooltipster("show");
        }
        else if(password !== passwordAgain){ //HESLO ZNOVU: Nerovná se, nebo je prázdné
            passwordAgainField.addClass("error");
            passwordAgainField.tooltipster({ content: "Hesla se neshodují." }).tooltipster("show");
        }

        else{
            notif.removeClass("red-dark").removeClass("orange-dark").removeClass("green-dark").removeClass("blue-dark");
            icon.attr("class", "");

            notif.addClass("blue-dark");
            icon.addClass("fa fa-fw fa-cog fa-spin");

            message.html("Server zpracovává formulář...");

            button.slideUp(1);
            form.slideUp(200);
            notif.slideDown(200);

            $.ajax({
                type: "POST",
                url: "/pwrecovery",
                data: form.serialize()
            }).success(function(data, status, jqxhr){
                notif.removeClass("blue-dark");
                icon.attr("class", "");
                message.html("");

                try{
                    var json = JSON.parse(data);

                    if(json.state == "success"){
                        notif.addClass("green-dark");
                        icon.addClass("fa fa-fw fa-check-circle");

                        message.html("Heslo úspěšně obnoveno.");
                        setTimeout(function(){
                            window.location.href = "/";
                        }, 2000);
                    }
                    else if(json.state == "error"){
                        notif.addClass("red-dark");
                        icon.addClass("fa fa-fw fa-times-circle");

                        message.html(json.message);

                        button.slideDown(400);
                    }
                    else{
                        notif.addClass("orange-dark");
                        icon.addClass("fa fa-fw fa-question-circle");
                        message.html("Server odpověděl neznámým stavem.");

                        button.slideDown(400);
                    }
                }
                catch(e){
                    notif.addClass("orange-dark");
                    icon.addClass("fa fa-fw fa-question-circle");

                    message.html("Server odpověděl neznámým stavem.");

                    button.slideDown(800);
                }
            });
        }
    });
}