<?php

class RegisterController extends Controller{
    function main($params){
        if(!$_POST){
            $this->view = "register";
        }
        else{
            $response = array();

            $model_user = new UserModel();
            $model_activation = new ActivationModel();

            $helper_mail = new MailHelper();
            $helper_renderer = new ExternalViewRendererHelper();
            $helper_config = new ConfigHelper();

            $username = $_POST['username'];
            $email = $_POST['email'];
            $birthdate = $_POST['birthdate'];
            $password = $_POST['password'];
            $passwordAgain = $_POST['passwordAgain'];
            $antispam = $_POST['antispam'];

            if( //POLE: Neodeslané pole
                !array_key_exists("username", $_POST) ||
                !array_key_exists("email", $_POST) ||
                !array_key_exists("birthdate", $_POST) ||
                !array_key_exists("password", $_POST) ||
                !array_key_exists("passwordAgain", $_POST) ||
                !array_key_exists("antispam", $_POST)
            ){
                $response['state'] = "error";
                $response['message'] = "Některé z polí je prázdné.";
            }


            //JMÉNO
            else if(empty($username)){ //JMÉNO: Prázdné
                $response['state'] = "error";
                $response['message'] = "Jméno je prázdné.";
            }
            else if(strlen($username) < 6){ //JMÉNO: Menší než 6
                $response['state'] = "error";
                $response['message'] = "Jméno je příliš krátké, má být minimálně 6 znaků dlouhé.";
            }
            else if(!preg_match("/^[a-z0-9_]+$/i", $username)){ //JMÉNO: Obsahuje nepovolené znaky
                $response['state'] = "error";
                $response['message'] = "Jméno obsahuje nedovolené znaky.";
            }
            else if($model_user->existsUsername($username)){
                $response['state'] = "error";
                $response['message'] = "Uživatel s tímto jménem již existuje.";
            }


            //EMAIL
            else if(empty($email)){ //EMAIL: Prázdný
                $response['state'] = "error";
                $response['message'] = "E-mailová adresa je prázdná.";
            }
            else if(!filter_var($email, FILTER_VALIDATE_EMAIL)){ //EMAIL: Nepovolený formát
                $response['state'] = "error";
                $response['message'] = "E-Mail je v nepovoleném formátu.";
            }
            else if($model_user->existsEmail($email)){
                $response['state'] = "error";
                $response['message'] = "Uživatel s touto E-Mailovou adresou již existuje.";
            }


            //DATUM NAROZENÍ
            else if(empty($birthdate)){ //DATUM NAROZENÍ: Prázdné
                $response['state'] = "error";
                $response['message'] = "Datum narození je prázdné.";
            }
            else if(DateTime::createFromFormat("d.m.Y", $birthdate) === FALSE){ //DATUM NAROZENÍ: Nepovolený formát
                $response['state'] = "error";
                $response['message'] = "Datum narození je v nepovoleném formátu.";
            }
            else if(date_diff(date_create($birthdate), date_create('now'))->y <= 10){ //DATUM NAROZENÍ: Limit stáří (10 let)
                $response['state'] = "error";
                $response['message'] = "Nejste způsobilí na registraci, stránka je určena pro uživatele s věkem 10 let a vyšším.";
            }


            //HESLO
            else if(empty($password)){ //HESLO: Prázdné
                $response['state'] = "error";
                $response['message'] = "Heslo je prázdné.";
            }
            else if(strlen($password) < 6){ //HESLO: Menší než 6
                $response['state'] = "error";
                $response['message'] = "Heslo je příliš krátké, má být minimálně 6 znaků dlouhé.";
            }


            //HESLO ZNOVU
            else if(empty($passwordAgain)){ //HESLO ZNOVU: Prázdné
                $response['state'] = "error";
                $response['message'] = "Heslo znovu je prázdné.";
            }
            else if($password !== $passwordAgain){ //HESLO ZNOVU: Neodpovídá
                $response['state'] = "error";
                $response['message'] = "Hesla nejsou stejná";
            }


            //ANTISPAM
            else if(empty($antispam)){ //ANTISPAM: Prázdný
                $response['state'] = "error";
                $response['message'] = "Odpověď na antispamovou otázku je prázdná.";
            }
            else if($antispam !== "96"){ //ANTISPAM: Odpověď nesprávná (72+24)
                $response['state'] = "error";
                $response['message'] = "Odpověď na antispamovou otázku je nesprávná.";
            }

            else{ //Vše se zdá OK, ideme na věc!
                $uniqid = uniqid(); //Speciální ID
                $password_crypted = password_hash($password, PASSWORD_BCRYPT); //Zašifrování hesla

                if($model_user->insertUser($username, $password_crypted, $email, $birthdate, $uniqid)){ //Vlož uživatele do DB
                    $token = $model_activation->generateToken($uniqid);

                    if($model_activation->insertActivation($uniqid, $token))
                        if($helper_mail->send($helper_config->getSiteEmail(), $email, "Aktivace účtu", $helper_renderer->renderView("mail_activate", array("token" => $token))))
                            $response['state'] = "success";
                        else{
                            $response['state'] = "error";
                            $response['message'] = "Aktivační E-Mail se nepodařilo poslat.";
                        }
                    else {
                        $response['state'] = "error";
                        $response['message'] = "Chyba databáze.";
                    }

                }
                else{
                    $response['state'] = "error";
                    $response['message'] = "Chyba databáze.";
                }
            }

            die(json_encode($response));
        }
    }
}