<?php

class Uzivatele {

    /**
     * Sůl, která se připojuje k heslu před hashováním
     */
    const SUl = '&@#55devpgh';

    /**
     * Ověří jestli uživatel už neexistuje podle mailu
     * @param string $mail Mail uživatele
     * @return string jestli uživatel existuje
     */
    public function overeniExistence($mail) {
        $existuje = Db::querySingle('
            SELECT COUNT(*)
            FROM uzivatele
            WHERE mail = ?
            LIMIT 1
        ', $mail);
        return $existuje;
    }

    /**
     * Vytvoří nového uživatele
     * @param string $mail Mail uživatele
     * @param string $heslo Heslo uživatele
     */
    public function vytvorUzivatele($mail, $heslo) {
        Db::query('
            INSERT INTO uzivatele 
            (mail, heslo, overeni)
            VALUES (?, SHA1(?), ?)
        ', $mail, $heslo . self::SUl, 'ne');
        $this->odesliOverujiciMail($mail, Db::getLastId());
    }

    /**
     * Odešle uživateli ověřující mail
     * @param string $adresa Mail uživatele
     * @param int $id Id uživatele
     * @return string Jestli se odeslání povedlo
     */
    public function odesliOverujiciMail($adresa, $id) {
        $hlavicka = 'From: machr.registrace@gmail.com';
        $hlavicka .= "\nMIME-Version: 1.0\n";
        $hlavicka .= "Content-Type: text/html; charset=\"utf-8\"\n";
        $predmet = 'Ověření registrace';
        $kod = sha1($id . 'hgf4řd&v@ds');
        $url = 'http://www.domena.cz/overeni.php?id=' . $id . '&kod=' . $kod;
        $vzkaz = 'Registrace proběhla úspěšně. Ověření mailu: <a href="'.$url.'">'.$url.'</a>';
        return $uspech = mb_send_mail($adresa, $predmet, $vzkaz, $hlavicka);
    }

    /**
     * Ověří mail uživatele
     * @param int $id Id uživatele
     */
    public function overMail($id) {
        Db::query('
            UPDATE uzivatele
            SET overeni = ?
            WHERE id_uzivatele = ?
        ', 'ano', $id);
    }

    /**
     * Najde mail uživatele podle jeho id
     * @param int $id Id uživatele
     * @return string Mail uživatele
     */
    public function najdiMail($id) {
        $uzivatel = Db::queryOne('
            SELECT mail
            FROM uzivatele
            WHERE id_uzivatele = ?
            LIMIT 1
        ', $id);
        return $uzivatel['mail'];
    }

    /**
     * Přihlásí uživatele
     * @param string $mail Mail uživatele
     * @param string $heslo Heslo uživatele
     * @return string Chybová hláška, pokud je
     */
    public function prihlasUzivatele($mail, $heslo) {
        $uzivatel = Db::queryOne('
            SELECT *
            FROM uzivatele
            WHERE mail = ? AND heslo = SHA1(?)
        ', $mail, $heslo . self::SUl);
        if (!$uzivatel) {
            return 'Neplatné uživatelské jméno nebo heslo.';
        } else {
            $_SESSION['id_uzivatele'] = $uzivatel['id_uzivatele'];
            $_SESSION['mail'] = $uzivatel['mail'];
            $_SESSION['overeni'] = $uzivatel['overeni'];
        }
    }

    /**
     * Obnoví zapomenuté heslo
     * @param string $mail Mail uživatele
     * @return string Jestli uživatel existuje
     */
    public function obnovHeslo($mail) {
        $existuje = $this->overeniExistence($mail);
        if ($existuje) {
            $heslo = $this->vygenerujHeslo();
            $this->zmenHeslo($mail, $heslo);
            $this->odesliObnovujiciMail($mail, $heslo);            
        }
        return $existuje;
    }

    /**
     * Vygeneruje nové heslo
     * @return string Nové vygenerované heslo
     */
    private function vygenerujHeslo() {
        mb_internal_encoding("UTF-8");
        $znaky = 'abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890';
        $delkaHesla = rand(8, 15);
        $heslo = '';
        for ($i = 0; $i <= $delkaHesla; $i++) {
            $cislo = rand(0, mb_strlen($znaky) - 1);
            $heslo .= $znaky[$cislo];
        }
        return $heslo;
    }

    /**
     * Změní uživateli heslo podle mailu
     * @param string $mail Mail uživatele
     * @param string $heslo Heslo uživatele
     */
    private function zmenHeslo($mail, $heslo) {
        Db::query('
            UPDATE uzivatele
            SET heslo = SHA1(?)
            WHERE mail = ?
        ', $heslo . self::SUl, $mail);
    }

    /**
     * Odešle mail s obnoveným heslem
     * @param string $adresa Mail uživatele
     * @param string $heslo Heslo uživatele
     * @return string Jestli se odeslání povedlo
     */
    private function odesliObnovujiciMail($adresa, $heslo) {
        $hlavicka = 'From: machr.registrace@gmail.com';
        $hlavicka .= "\nMIME-Version: 1.0\n";
        $hlavicka .= "Content-Type: text/html; charset=\"utf-8\"\n";
        $predmet = 'Obnovení hesla';
        $vzkaz = 'Heslo bylo úspěšně obnoveno. <br /> Mail: ' . $adresa . '<br /> Heslo: ' . $heslo;
        return $uspech = mb_send_mail($adresa, $predmet, $vzkaz, $hlavicka);
    }

}
