<?php

class UserModel
{
    private $db;

    public function __construct()
    {
        $this->db = DbHelper::instance()->db();
    }

    public function insertUser($username, $password, $email, $birthdate, $uniqid)
    {
        $stmt = $this->db->prepare("INSERT INTO users (username, password, email, birthdate, uniqid, active) VALUES (:user, :pass, :email, :birth, :uniqid, :active);");

        return $stmt->execute(array(
            ":user" => $username,
            ":pass" => $password,
            ":email" => $email,
            ":birth" => $birthdate,
            ":uniqid" => $uniqid,
            ":active" => 0
        ));
    }

    public function existsUsername($username)
    {
        $stmt = $this->db->prepare("SELECT COUNT(*) FROM users WHERE username=:user;");
        $stmt->execute(array(
            ":user" => $username
        ));

        return $stmt->fetchColumn(0) > 0;
    }

    public function existsEmail($email)
    {
        $stmt = $this->db->prepare("SELECT COUNT(*) FROM users WHERE email=:email;");
        $stmt->execute(array(
            ":email" => $email
        ));

        return $stmt->fetchColumn(0) > 0;
    }

    public function existsId($userid)
    {
        $stmt = $this->db->prepare("SELECT COUNT(*) FROM users WHERE uniqid=:userid;");
        $stmt->execute(array(
            ":userid" => $userid
        ));

        return $stmt->fetchColumn(0) > 0;
    }

    public function activate($userid)
    {
        $stmt = $this->db->prepare("UPDATE users SET active=:active WHERE uniqid=:userid;");

        return $stmt->execute(array(
            ":userid" => $userid,
            ":active" => 1
        ));
    }

    public function testPassword($email, $password)
    {
        $stmt = $this->db->prepare("SELECT password FROM users WHERE email=:email LIMIT 1;");
        $stmt->execute(array(
            ":email" => $email
        ));

        $hash = $stmt->fetchColumn(0);

        return password_verify($password, $hash);
    }

    public function getUserId_email($email)
    {
        $stmt = $this->db->prepare("SELECT uniqid FROM users WHERE email=:email LIMIT 1;");
        $stmt->execute(array(
            ":email" => $email
        ));

        return $stmt->fetchColumn(0);
    }

    public function updatePassword($userid, $password){
        $stmt = $this->db->prepare("UPDATE users SET password=:pw WHERE uniqid=:userid;");
        return $stmt->execute(array(
            ":pw" => $password,
            ":userid" => $userid
        ));
    }
}